### v0.4.0 (2025-11-12)
- Added BigQuery as a supported data source
- Added new visualizations: density heatmap, polar scatter plot, and polar line plot.
- Minor changes in Studio UI

### v0.3.0 (2025-08-29)
- Major changes in Studio UI; now more stable & smooth
- Can set reasoing effort via settings in Studio UI
- Can set system prompt via settings in Studio UI

#### v0.2.2 (2025-07-31)
- Fix for `'function' object has no attribute 'key'`
- Changed `pkg_resources` dependency to `importlib.resources`

#### v0.2.1 (2025-07-24)
- Added Support For Microsoft SQL Server Databases

### v0.2.0 (2025-07-01)
- The Studio Interface: Now use Zaturn with an inbuilt UI, with your own LLM API.
- Refactored MCP Code.
- Removed `show_query_result` tool. Query results will now be returned directly.

#### v0.1.7 (2025-05-06)
- Ensured Read-Only For SQLite and MySQL

#### v0.1.6 (2025-04-25)
- Added Clickhouse Support

#### v0.1.5 (2025-04-22)
- Changed plotting library to plotly instead of seaborn
- Fixed labeling issues in visualizations
